@@ -21,7 +21,8 @@ typedef Eo Efl_Part;
  * widget's theme.
  *
  * Part proxy objects have a special lifetime that is limited to one and only
- * one function call.
+ * one function call. This behavior is implemented in efl_part() which call
+ * Efl.Part.part_get(). Calling Efl.Part.part_get() directly should be avoided.
  *
  * In other words, the caller does not hold a reference to this proxy object.
  * It may be possible, in languages that allow it, to get an extra reference to
@@ -41,20 +42,20 @@ typedef Eo Efl_Part;
  */
 #define EFL_PART_INTERFACE efl_part_interface_get()
 
-EWAPI const Eo_Class *efl_part_interface_get(void);
+EWAPI const Efl_Class *efl_part_interface_get(void);
 
+#ifdef EFL_PART_PROTECTED
 /**
  * @brief Get a proxy object referring to a part of an object.
  *
- * The returned object is valid for only a single function call.
- *
+ * @param[in] obj The object.
  * @param[in] name The part name.
  *
  * @return A (proxy) object, valid for a single call.
  *
  * @ingroup Efl_Part
  */
-EOAPI Eo_Base *efl_part(const Eo *obj, const char *name);
-
+EOAPI Efl_Object *efl_part_get(const Eo *obj, const char *name);
+#endif
 
 #endif
