@@ -19,20 +19,12 @@ typedef Eo Eldbus_Model_Arguments;
  */
 #define ELDBUS_MODEL_ARGUMENTS_CLASS eldbus_model_arguments_class_get()
 
-EWAPI const Eo_Class *eldbus_model_arguments_class_get(void);
-
-/**
- * @brief Name of the argument
- *
- * @return Argument name
- *
- * @ingroup Eldbus_Model_Arguments
- */
-EOAPI const char *eldbus_model_arguments_name_get(const Eo *obj);
+EWAPI const Efl_Class *eldbus_model_arguments_class_get(void);
 
 /**
  * @brief Custom Eldbus_Model_Arguments constructor.
  *
+ * @param[in] obj The object.
  * @param[in] proxy Eldbus proxy
  * @param[in] name Name
  * @param[in] arguments The introspected arguments
@@ -41,7 +33,17 @@ EOAPI const char *eldbus_model_arguments_name_get(const Eo *obj);
  *
  * @ingroup Eldbus_Model_Arguments
  */
-EOAPI void eldbus_model_arguments_constructor(Eo *obj, Eldbus_Proxy *proxy, const char *name, const Eina_List *arguments);
+EOAPI void eldbus_model_arguments_custom_constructor(Eo *obj, Eldbus_Proxy *proxy, const char *name, const Eina_List *arguments);
 
+/**
+ * @brief Name of the argument
+ *
+ * @param[in] obj The object.
+ *
+ * @return Argument name
+ *
+ * @ingroup Eldbus_Model_Arguments
+ */
+EOAPI const char *eldbus_model_arguments_arg_name_get(const Eo *obj);
 
 #endif
