@@ -13,7 +13,7 @@ typedef Eo Efl_Ui_Flip;
 
 /** Efl UI flip mode
  *
- * @ingroup Efl_Ui_Flip
+ * @ingroup Efl_Ui
  */
 typedef enum
 {
@@ -34,7 +34,7 @@ typedef enum
 
 /** Efl UI flip interaction
  *
- * @ingroup Efl_Ui_Flip
+ * @ingroup Efl_Ui
  */
 typedef enum
 {
@@ -72,6 +72,7 @@ EWAPI const Efl_Class *efl_ui_flip_class_get(void);
  * #ELM_FLIP_ROTATE_XZ_CENTER_AXIS or #ELM_FLIP_ROTATE_YZ_CENTER_AXIS to
  * happen, those can only be achieved with @ref efl_ui_flip_go.
  *
+ * @param[in] obj The object.
  * @param[in] mode The interactive flip mode to use.
  *
  * @ingroup Efl_Ui_Flip
@@ -81,6 +82,8 @@ EOAPI void efl_ui_flip_interaction_set(Eo *obj, Efl_Ui_Flip_Interaction mode);
 /**
  * @brief Get the interactive flip mode.
  *
+ * @param[in] obj The object.
+ *
  * @return The interactive flip mode to use.
  *
  * @ingroup Efl_Ui_Flip
@@ -90,6 +93,8 @@ EOAPI Efl_Ui_Flip_Interaction efl_ui_flip_interaction_get(const Eo *obj);
 /**
  * @brief Get flip front visibility state.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if front front is showing, @c false if the back is showing.
  *
  * @ingroup Efl_Ui_Flip
@@ -114,52 +119,56 @@ EOAPI Eina_Bool efl_ui_flip_front_visible_get(const Eo *obj);
  *
  * See also @ref efl_ui_flip_interaction_set.
  *
+ * @param[in] obj The object.
  * @param[in] dir The hit area to set.
  * @param[in] hitsize The amount of that dimension (0.0 to 1.0) to use.
  *
  * @ingroup Efl_Ui_Flip
  */
-EOAPI void efl_ui_flip_interaction_direction_hitsize_set(Eo *obj, Efl_Orient dir, double hitsize);
+EOAPI void efl_ui_flip_interaction_direction_hitsize_set(Eo *obj, Efl_Ui_Dir dir, double hitsize);
 
 /**
  * @brief Get the amount of the flip that is sensitive to interactive flip.
  *
+ * @param[in] obj The object.
  * @param[in] dir The direction to check.
  *
  * @return The size set for that direction.
  *
  * @ingroup Efl_Ui_Flip
  */
-EOAPI double efl_ui_flip_interaction_direction_hitsize_get(Eo *obj, Efl_Orient dir);
+EOAPI double efl_ui_flip_interaction_direction_hitsize_get(Eo *obj, Efl_Ui_Dir dir);
 
 /**
  * @brief Set which directions of the flip respond to interactive flip
  *
  * By default all directions are disabled, so you may want to enable the
  * desired directions for flipping if you need interactive flipping. You must
- * call this function once for each direction that should be enabled.
+ * call this function once for each direction that's enabled.
  *
  * You can also set the appropriate hit area size by calling
  * @ref efl_ui_flip_interaction_direction_hitsize_set. By default, a minimum
  * hit area will be created on the opposite edge of the flip.
  *
+ * @param[in] obj The object.
  * @param[in] dir The direction to change.
  * @param[in] enabled If that direction is enabled or not.
  *
  * @ingroup Efl_Ui_Flip
  */
-EOAPI void efl_ui_flip_interaction_direction_enabled_set(Eo *obj, Efl_Orient dir, Eina_Bool enabled);
+EOAPI void efl_ui_flip_interaction_direction_enabled_set(Eo *obj, Efl_Ui_Dir dir, Eina_Bool enabled);
 
 /**
  * @brief Get the enabled state of that flip direction.
  *
+ * @param[in] obj The object.
  * @param[in] dir The direction to check.
  *
  * @return If that direction is enabled or not.
  *
  * @ingroup Efl_Ui_Flip
  */
-EOAPI Eina_Bool efl_ui_flip_interaction_direction_enabled_get(Eo *obj, Efl_Orient dir);
+EOAPI Eina_Bool efl_ui_flip_interaction_direction_enabled_get(Eo *obj, Efl_Ui_Dir dir);
 
 /**
  * @brief Runs the flip animation.
@@ -167,7 +176,7 @@ EOAPI Eina_Bool efl_ui_flip_interaction_direction_enabled_get(Eo *obj, Efl_Orien
  * Flips the front and back contents using the @c mode animation. This
  * effectively hides the currently visible content and shows the hidden one.
  *
- * There a number of possible animations to use for the flipping, these being
+ * There a number of possible animations to use for flipping, namely
  * #ELM_FLIP_ROTATE_X_CENTER_AXIS (rotate the currently visible content around
  * a horizontal axis in the middle of its height, the other content is shown as
  * the other side of the flip), #ELM_FLIP_ROTATE_Y_CENTER_AXIS (rotate the
@@ -179,24 +188,25 @@ EOAPI Eina_Bool efl_ui_flip_interaction_direction_enabled_get(Eo *obj, Efl_Orien
  * currently visible content around a diagonal axis in the middle of its
  * height, the other content is hown as the other side of the flip).
  * #ELM_FLIP_CUBE_LEFT (rotate the currently visible content to the left as if
- * the flip was a cube, the other content is show as the right face of the
+ * the flip was a cube, the other content is shown as the right face of the
  * cube), #ELM_FLIP_CUBE_RIGHT (rotate the currently visible content to the
- * right as if the flip was a cube, the other content is show as the left face
+ * right as if the flip was a cube, the other content is shown as the left face
  * of the cube), #ELM_FLIP_CUBE_UP (rotate the currently visible content up as
- * if the flip was a cube, the other content is show as the bottom face of the
+ * if the flip was a cube, the other content is shown as the bottom face of the
  * cube), #ELM_FLIP_CUBE_DOWN (rotate the currently visible content down as if
- * the flip was a cube, the other content is show as the upper face of the
+ * the flip was a cube, the other content is shown as the upper face of the
  * cube), #ELM_FLIP_PAGE_LEFT (move the currently visible content to the left
  * as if the flip was a book, the other content is shown as the page below
  * that), #ELM_FLIP_PAGE_RIGHT (move the currently visible content to the right
- * s if the flip was a book, the other content is shown as the page below
- * that), #ELM_FLIP_PAGE_UP (move the currently visible content up as if the
- * flip was a book, the other content is shown as the page below that),
+ * as if the flip was a book, the other content is shown as the page below it),
+ * #ELM_FLIP_PAGE_UP (move the currently visible content up as if the flip was
+ * a book, the other content is shown as the page below it),
  * #ELM_FLIP_PAGE_DOWN (move the currently visible content down as if the flip
  * was a book, the other content is shown as the page below that) and
  * #ELM_FLIP_CROSS_FADE (fade out the currently visible content, while fading
  * in the invisible content).
  *
+ * @param[in] obj The object.
  * @param[in] mode The mode type.
  *
  * @ingroup Efl_Ui_Flip
@@ -207,9 +217,9 @@ EOAPI void efl_ui_flip_go(Eo *obj, Efl_Ui_Flip_Mode mode);
  * @brief Runs the flip animation to front or back.
  *
  * Flips the front and back contents using the @c mode animation. This
- * effectively hides the currently visible content and shows  he hidden one.
+ * effectively hides the currently visible content and shows he hidden one.
  *
- * There a number of possible animations to use for the flipping, these being
+ * There a number of possible animations to use for flipping, namely
  * #ELM_FLIP_ROTATE_X_CENTER_AXIS (rotate the currently visible content around
  * a horizontal axis in the middle of its height, the other content is shown as
  * the other side of the flip), #ELM_FLIP_ROTATE_Y_CENTER_AXIS (rotate the
@@ -219,24 +229,25 @@ EOAPI void efl_ui_flip_go(Eo *obj, Efl_Ui_Flip_Mode mode);
  * a diagonal axis in the middle of its width, the other content is shown as
  * the other side of the flip), #ELM_FLIP_ROTATE_YZ_CENTER_AXIS (rotate the
  * currently visible content around a diagonal axis in the middle of its
- * height, the other content is hown as the other side of the flip).
+ * height, the other content is shown as the other side of the flip).
  * #ELM_FLIP_CUBE_LEFT (rotate the currently visible content to the left as if
  * the flip was a cube, the other content is show as the right face of the
  * cube), #ELM_FLIP_CUBE_RIGHT (rotate the currently visible content to the
  * right as if the flip was a cube, the other content is show as the left face
  * of the cube), #ELM_FLIP_CUBE_UP (rotate the currently visible content up as
- * if the flip was a cube, the other content is show as the bottom face of the
+ * if the flip was a cube, the other content is shown as the bottom face of the
  * cube), #ELM_FLIP_CUBE_DOWN (rotate the currently visible content down as if
- * the flip was a cube, the other content is show as the upper face of the
+ * the flip was a cube, the other content is shown as the upper face of the
  * cube), #ELM_FLIP_PAGE_LEFT (move the currently visible content to the left
  * as if the flip was a book, the other content is shown as the page below
  * that), #ELM_FLIP_PAGE_RIGHT (move the currently visible content to the right
- * s if the flip was a book, the other content is shown as the page below
- * that), #ELM_FLIP_PAGE_UP (move the currently visible content up as if the
- * flip was a book, the other content is shown as the page below that) and
+ * as if the flip was a book, the other content is shown as the page below it),
+ * #ELM_FLIP_PAGE_UP (move the currently visible content up as if the flip was
+ * a book, the other content is shown as the page below it) and
  * #ELM_FLIP_PAGE_DOWN (move the currently visible content down as if the flip
  * was a book, the other content is shown as the page below that).
  *
+ * @param[in] obj The object.
  * @param[in] front If @c true, makes front visible, otherwise makes back.
  * @param[in] mode The mode type.
  *
