@@ -19,7 +19,6 @@ typedef Eo Efl_Canvas_Surface_Tbm;
  */
 #define EFL_CANVAS_SURFACE_TBM_CLASS efl_canvas_surface_tbm_class_get()
 
-EWAPI const Eo_Class *efl_canvas_surface_tbm_class_get(void);
-
+EWAPI const Efl_Class *efl_canvas_surface_tbm_class_get(void);
 
 #endif
