@@ -22,20 +22,29 @@ typedef Eo Evas_Canvas3D_Node;
 EWAPI const Efl_Class *evas_canvas3d_node_class_get(void);
 
 /**
- * @brief Constructor.
+ * @brief Get the type of the given node.
  *
+ * See also @ref evas_canvas3d_node_member_add.
+ *
+ * Type can only be set before finalize.
+ *
+ * @param[in] obj The object.
  * @param[in] type Node type
  *
  * @ingroup Evas_Canvas3D_Node
  */
-EOAPI void evas_canvas3d_node_constructor(Eo *obj, Evas_Canvas3D_Node_Type type);
+EOAPI void evas_canvas3d_node_type_set(Eo *obj, Evas_Canvas3D_Node_Type type);
 
 /**
  * @brief Get the type of the given node.
  *
  * See also @ref evas_canvas3d_node_member_add.
  *
- * @return The type of the given node.
+ * If the object is not node object, returns @c unknown.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Node type
  *
  * @ingroup Evas_Canvas3D_Node
  */
@@ -45,10 +54,11 @@ EOAPI Evas_Canvas3D_Node_Type evas_canvas3d_node_type_get(const Eo *obj);
  * @brief Add a member node to the given node.
  *
  * Nodes can be constructed into N-ary tree structure like other ordinary scene
- * graph. Basically a node inherit transforms from its parent.
+ * graphs. A node inherit transforms from its parent.
  *
  * See also @ref evas_canvas3d_node_parent_get.
  *
+ * @param[in] obj The object.
  * @param[in] member Node object to be added.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -60,6 +70,7 @@ EOAPI void evas_canvas3d_node_member_add(Eo *obj, Evas_Canvas3D_Node *member);
  *
  * See also @ref evas_canvas3d_node_member_add.
  *
+ * @param[in] obj The object.
  * @param[in] member Member node to be deleted from the given node.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -71,6 +82,8 @@ EOAPI void evas_canvas3d_node_member_del(Eo *obj, Evas_Canvas3D_Node *member);
  *
  * See also @ref evas_canvas3d_node_member_add.
  *
+ * @param[in] obj The object.
+ *
  * @return The parent node of the given node.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -82,6 +95,8 @@ EOAPI Evas_Canvas3D_Node *evas_canvas3d_node_parent_get(const Eo *obj);
  *
  * See also @ref evas_canvas3d_node_member_add.
  *
+ * @param[in] obj The object.
+ *
  * @return The list of member nodes if any or @c null if there are none.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -91,6 +106,8 @@ EOAPI const Eina_List *evas_canvas3d_node_member_list_get(const Eo *obj);
 /**
  * @brief Get hash table of scenes using this node as root.
  *
+ * @param[in] obj The object.
+ *
  * @return scenes using this node as root. FIXME: Actually a scene, not object.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -107,6 +124,7 @@ EOAPI Eina_Hash *evas_canvas3d_node_scene_root_get(Eo *obj);
  *
  * See also @ref evas_canvas3d_node_position_inherit_set.
  *
+ * @param[in] obj The object.
  * @param[in] x X coordinate of the position.
  * @param[in] y Y coordinate of the position.
  * @param[in] z Z coordinate of the position.
@@ -125,6 +143,7 @@ EOAPI void evas_canvas3d_node_position_set(Eo *obj, Evas_Real x, Evas_Real y, Ev
  *
  * See also @ref evas_canvas3d_node_orientation_inherit_set.
  *
+ * @param[in] obj The object.
  * @param[in] x X term of the orientation quaternion (w, x, y, z.
  * @param[in] y Y term of the orientation quaternion (w, x, y, z.
  * @param[in] z Z term of the orientation quaternion (w, x, y, z.
@@ -139,6 +158,7 @@ EOAPI void evas_canvas3d_node_orientation_set(Eo *obj, Evas_Real x, Evas_Real y,
  *
  * See also @ref evas_canvas3d_node_orientation_set.
  *
+ * @param[in] obj The object.
  * @param[in] angle Rotation angle.
  * @param[in] x X term of the rotation axis.
  * @param[in] y Y term of the rotation axis.
@@ -159,6 +179,7 @@ EOAPI void evas_canvas3d_node_orientation_angle_axis_set(Eo *obj, Evas_Real angl
  *
  * See also @ref evas_canvas3d_node_scale_inherit_set.
  *
+ * @param[in] obj The object.
  * @param[in] x Scale factor along X-axis.
  * @param[in] y Scale factor along Y-axis.
  * @param[in] z Scale factor along Z-axis.
@@ -172,6 +193,7 @@ EOAPI void evas_canvas3d_node_scale_set(Eo *obj, Evas_Real x, Evas_Real y, Evas_
  *
  * See also @ref evas_canvas3d_node_position_set.
  *
+ * @param[in] obj The object.
  * @param[in] space The given node.
  * @param[out] x Pointer to receive X coordinate of the position.
  * @param[out] y Pointer to receive Y coordinate of the position.
@@ -186,6 +208,7 @@ EOAPI void evas_canvas3d_node_position_get(const Eo *obj, Evas_Canvas3D_Space sp
  *
  * See also @ref evas_canvas3d_node_orientation_set.
  *
+ * @param[in] obj The object.
  * @param[in] space The given node.
  * @param[out] x Pointer to receive X term of the orientation quaternion.
  * @param[out] y Pointer to receive Y term of the orientation quaternion.
@@ -201,6 +224,7 @@ EOAPI void evas_canvas3d_node_orientation_get(const Eo *obj, Evas_Canvas3D_Space
  *
  * See also @ref evas_canvas3d_node_scale_get.
  *
+ * @param[in] obj The object.
  * @param[in] space The given node.
  * @param[out] x Pointer to receive Scale factor along X-axis.
  * @param[out] y Pointer to receive Scale factor along X-axis.
@@ -219,6 +243,7 @@ EOAPI void evas_canvas3d_node_scale_get(const Eo *obj, Evas_Canvas3D_Space space
  *
  * See also @ref evas_canvas3d_node_orientation_set.
  *
+ * @param[in] obj The object.
  * @param[in] target_space Space where the target position belongs to.
  * @param[in] x X coordinate of the target position.
  * @param[in] y Y coordinate of the target position.
@@ -240,6 +265,7 @@ EOAPI void evas_canvas3d_node_look_at_set(Eo *obj, Evas_Canvas3D_Space target_sp
  *
  * See also @ref evas_canvas3d_node_member_add.
  *
+ * @param[in] obj The object.
  * @param[in] mesh The mesh to be added.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -255,6 +281,7 @@ EOAPI void evas_canvas3d_node_mesh_add(Eo *obj, Evas_Canvas3D_Mesh *mesh);
  *
  * See also @ref evas_canvas3d_node_mesh_add.
  *
+ * @param[in] obj The object.
  * @param[in] mesh The mesh to be deleted.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -270,6 +297,8 @@ EOAPI void evas_canvas3d_node_mesh_del(Eo *obj, Evas_Canvas3D_Mesh *mesh);
  *
  * See also @ref evas_canvas3d_node_mesh_add.
  *
+ * @param[in] obj The object.
+ *
  * @return The list of meshes if any, or @c null if there're none.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -279,6 +308,7 @@ EOAPI const Eina_List *evas_canvas3d_node_mesh_list_get(const Eo *obj);
 /**
  * @brief Get axis-aligned bounding box (AABB) of the given node.
  *
+ * @param[in] obj The object.
  * @param[in] x Pointer to receive X coordinate of the first point of AABB.
  * @param[in] y Pointer to receive Y coordinate of the first point of AABB.
  * @param[in] z Pointer to receive Z coordinate of the first point of AABB.
@@ -293,6 +323,7 @@ EOAPI void evas_canvas3d_node_bounding_box_get(Eo *obj, Evas_Real *x, Evas_Real
 /**
  * @brief Get bounding sphere of the given node.
  *
+ * @param[in] obj The object.
  * @param[in] x Pointer to receive X coordinate of the center of sphere.
  * @param[in] y Pointer to receive Y coordinate of the center of sphere.
  * @param[in] z Pointer to receive Z coordinate of center of sphere.
@@ -306,9 +337,10 @@ EOAPI void evas_canvas3d_node_bounding_sphere_get(Eo *obj, Evas_Real *x, Evas_Re
  * @brief Set the position inheritance flag of the given node.
  *
  * When inheritance is enabled, a node's world space position is determined by
- * adding the parent node's world position and the node's position, otherwise,
+ * adding the parent node's world position and the node's position. Otherwise
  * the node's position will be the world space position.
  *
+ * @param[in] obj The object.
  * @param[in] inherit Whether to inherit parent position.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -320,6 +352,8 @@ EOAPI void evas_canvas3d_node_position_inherit_set(Eo *obj, Eina_Bool inherit);
  *
  * See also @ref evas_canvas3d_node_position_inherit_set.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether to inherit parent position.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -331,9 +365,10 @@ EOAPI Eina_Bool evas_canvas3d_node_position_inherit_get(const Eo *obj);
  *
  * When inheritance is enabled, a node's world space orientation is determined
  * by multiplying the parent node's world orientation and the node's
- * orientation, otherwise, the node's orientation will be the world space
+ * orientation. Otherwise the node's orientation will be the world space
  * orientation.
  *
+ * @param[in] obj The object.
  * @param[in] inherit Whether to inherit parent orientation.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -345,6 +380,8 @@ EOAPI void evas_canvas3d_node_orientation_inherit_set(Eo *obj, Eina_Bool inherit
  *
  * See also @ref evas_canvas3d_node_orientation_inherit_set.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether to inherit parent orientation.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -355,9 +392,10 @@ EOAPI Eina_Bool evas_canvas3d_node_orientation_inherit_get(const Eo *obj);
  * @brief Set the scale inheritance flag of the given node.
  *
  * When inheritance is enabled, a node's world space scale is determined by
- * multiplying the parent node's world scale and the node's scale, otherwise,
+ * multiplying the parent node's world scale and the node's scale. Otherwise
  * the node's scale will be the world space scale.
  *
+ * @param[in] obj The object.
  * @param[in] inherit Whether to inherit parent scale.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -369,6 +407,8 @@ EOAPI void evas_canvas3d_node_scale_inherit_set(Eo *obj, Eina_Bool inherit);
  *
  * See also @ref evas_canvas3d_node_scale_inherit_set.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether to inherit parent scale.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -383,6 +423,7 @@ EOAPI Eina_Bool evas_canvas3d_node_scale_inherit_get(const Eo *obj);
  *
  * See also @ref evas_canvas3d_node_member_add.
  *
+ * @param[in] obj The object.
  * @param[in] camera The camera of the given node if any, or @c null if
  * there're none.
  *
@@ -395,6 +436,8 @@ EOAPI void evas_canvas3d_node_camera_set(Eo *obj, Evas_Canvas3D_Object *camera);
  *
  * See also @ref evas_canvas3d_node_camera_set.
  *
+ * @param[in] obj The object.
+ *
  * @return The camera of the given node if any, or @c null if there're none.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -409,6 +452,7 @@ EOAPI Evas_Canvas3D_Object *evas_canvas3d_node_camera_get(const Eo *obj);
  *
  * See also @ref evas_canvas3d_node_member_add.
  *
+ * @param[in] obj The object.
  * @param[in] light The light of the given node if any, or @c null if there're
  * none.
  *
@@ -421,6 +465,8 @@ EOAPI void evas_canvas3d_node_light_set(Eo *obj, Evas_Canvas3D_Light *light);
  *
  * See also @ref evas_canvas3d_node_light_set.
  *
+ * @param[in] obj The object.
+ *
  * @return The light of the given node if any, or @c null if there're none.
  *
  * @ingroup Evas_Canvas3D_Node
@@ -438,12 +484,13 @@ EOAPI Evas_Canvas3D_Light *evas_canvas3d_node_light_get(const Eo *obj);
  *
  * See also @ref evas_canvas3d_node_mesh_add.
  *
+ * @param[in] obj The object.
  * @param[in] mesh The given mesh.
  * @param[in] frame The animation frame number.
  *
  * @ingroup Evas_Canvas3D_Node
  */
-EOAPI void evas_canvas3d_node_mesh_frame_set(Eo *obj, Evas_Canvas3D_Mesh * mesh, int frame);
+EOAPI void evas_canvas3d_node_mesh_frame_set(Eo *obj, Evas_Canvas3D_Mesh *mesh, int frame);
 
 /**
  * @brief Set the animation frame number of the given node for the given mesh.
@@ -454,17 +501,19 @@ EOAPI void evas_canvas3d_node_mesh_frame_set(Eo *obj, Evas_Canvas3D_Mesh * mesh,
  *
  * See also @ref evas_canvas3d_node_mesh_add.
  *
+ * @param[in] obj The object.
  * @param[in] mesh The given mesh.
  *
  * @return The animation frame number.
  *
  * @ingroup Evas_Canvas3D_Node
  */
-EOAPI int evas_canvas3d_node_mesh_frame_get(const Eo *obj, Evas_Canvas3D_Mesh * mesh);
+EOAPI int evas_canvas3d_node_mesh_frame_get(const Eo *obj, Evas_Canvas3D_Mesh *mesh);
 
 /**
  * @brief Set behavior of node like billboard object.
  *
+ * @param[in] obj The object.
  * @param[in] target The pointer to target node for billboard object, or
  * @c null if there're none.
  *
@@ -477,6 +526,8 @@ EOAPI void evas_canvas3d_node_billboard_target_set(Eo *obj, Evas_Canvas3D_Node *
  *
  * See also @ref evas_canvas3d_node_billboard_target_set.
  *
+ * @param[in] obj The object.
+ *
  * @return The pointer to target node for billboard object, or @c null if
  * there're none.
  *
@@ -487,6 +538,7 @@ EOAPI Evas_Canvas3D_Node *evas_canvas3d_node_billboard_target_get(const Eo *obj)
 /**
  * @brief Enable behavior of node like LOD object.
  *
+ * @param[in] obj The object.
  * @param[in] enable status property (true/false)
  *
  * @ingroup Evas_Canvas3D_Node
@@ -498,6 +550,8 @@ EOAPI void evas_canvas3d_node_lod_enable_set(Eo *obj, Eina_Bool enable);
  *
  * See also @ref evas_canvas3d_node_lod_enable_set.
  *
+ * @param[in] obj The object.
+ *
  * @return status property (true/false)
  *
  * @ingroup Evas_Canvas3D_Node
